@@ -95,9 +95,10 @@ query_axfr(struct nsd *nsd, struct query *query)
 	}
 
 	/* Add zone RRs until answer is full.  */
-	assert(query->axfr_current_domain);
-
-	do {
+	while (query->axfr_current_domain != NULL &&
+			domain_is_subdomain(query->axfr_current_domain,
+					    query->axfr_zone->apex))
+	{
 		if (!query->axfr_current_rrset) {
 			query->axfr_current_rrset = domain_find_any_rrset(
 				query->axfr_current_domain,
@@ -128,9 +129,6 @@ query_axfr(struct nsd *nsd, struct query *query)
 		query->axfr_current_domain
 			= domain_next(query->axfr_current_domain);
 	}
-	while (query->axfr_current_domain != NULL &&
-			domain_is_subdomain(query->axfr_current_domain,
-					    query->axfr_zone->apex));
 
 	/* Add terminating SOA RR.  */
 	assert(query->axfr_zone->soa_rrset->rr_count == 1);
