@@ -83,48 +83,49 @@ extern int yydebug;
     VAR_DO_IP6 = 293,
     VAR_TCP_MSS = 294,
     VAR_OUTGOING_TCP_MSS = 295,
-    VAR_ZONEFILE = 296,
-    VAR_ZONE = 297,
-    VAR_ALLOW_NOTIFY = 298,
-    VAR_REQUEST_XFR = 299,
-    VAR_NOTIFY = 300,
-    VAR_PROVIDE_XFR = 301,
-    VAR_NOTIFY_RETRY = 302,
-    VAR_OUTGOING_INTERFACE = 303,
-    VAR_ALLOW_AXFR_FALLBACK = 304,
-    VAR_KEY = 305,
-    VAR_ALGORITHM = 306,
-    VAR_SECRET = 307,
-    VAR_AXFR = 308,
-    VAR_UDP = 309,
-    VAR_VERBOSITY = 310,
-    VAR_HIDE_VERSION = 311,
-    VAR_PATTERN = 312,
-    VAR_INCLUDEPATTERN = 313,
-    VAR_ZONELISTFILE = 314,
-    VAR_REMOTE_CONTROL = 315,
-    VAR_CONTROL_ENABLE = 316,
-    VAR_CONTROL_INTERFACE = 317,
-    VAR_CONTROL_PORT = 318,
-    VAR_SERVER_KEY_FILE = 319,
-    VAR_SERVER_CERT_FILE = 320,
-    VAR_CONTROL_KEY_FILE = 321,
-    VAR_CONTROL_CERT_FILE = 322,
-    VAR_XFRDIR = 323,
-    VAR_RRL_SIZE = 324,
-    VAR_RRL_RATELIMIT = 325,
-    VAR_RRL_SLIP = 326,
-    VAR_RRL_IPV4_PREFIX_LENGTH = 327,
-    VAR_RRL_IPV6_PREFIX_LENGTH = 328,
-    VAR_RRL_WHITELIST_RATELIMIT = 329,
-    VAR_RRL_WHITELIST = 330,
-    VAR_ZONEFILES_CHECK = 331,
-    VAR_ZONEFILES_WRITE = 332,
-    VAR_LOG_TIME_ASCII = 333,
-    VAR_ROUND_ROBIN = 334,
-    VAR_ZONESTATS = 335,
-    VAR_REUSEPORT = 336,
-    VAR_VERSION = 337
+    VAR_IP_FREEBIND = 296,
+    VAR_ZONEFILE = 297,
+    VAR_ZONE = 298,
+    VAR_ALLOW_NOTIFY = 299,
+    VAR_REQUEST_XFR = 300,
+    VAR_NOTIFY = 301,
+    VAR_PROVIDE_XFR = 302,
+    VAR_NOTIFY_RETRY = 303,
+    VAR_OUTGOING_INTERFACE = 304,
+    VAR_ALLOW_AXFR_FALLBACK = 305,
+    VAR_KEY = 306,
+    VAR_ALGORITHM = 307,
+    VAR_SECRET = 308,
+    VAR_AXFR = 309,
+    VAR_UDP = 310,
+    VAR_VERBOSITY = 311,
+    VAR_HIDE_VERSION = 312,
+    VAR_PATTERN = 313,
+    VAR_INCLUDEPATTERN = 314,
+    VAR_ZONELISTFILE = 315,
+    VAR_REMOTE_CONTROL = 316,
+    VAR_CONTROL_ENABLE = 317,
+    VAR_CONTROL_INTERFACE = 318,
+    VAR_CONTROL_PORT = 319,
+    VAR_SERVER_KEY_FILE = 320,
+    VAR_SERVER_CERT_FILE = 321,
+    VAR_CONTROL_KEY_FILE = 322,
+    VAR_CONTROL_CERT_FILE = 323,
+    VAR_XFRDIR = 324,
+    VAR_RRL_SIZE = 325,
+    VAR_RRL_RATELIMIT = 326,
+    VAR_RRL_SLIP = 327,
+    VAR_RRL_IPV4_PREFIX_LENGTH = 328,
+    VAR_RRL_IPV6_PREFIX_LENGTH = 329,
+    VAR_RRL_WHITELIST_RATELIMIT = 330,
+    VAR_RRL_WHITELIST = 331,
+    VAR_ZONEFILES_CHECK = 332,
+    VAR_ZONEFILES_WRITE = 333,
+    VAR_LOG_TIME_ASCII = 334,
+    VAR_ROUND_ROBIN = 335,
+    VAR_ZONESTATS = 336,
+    VAR_REUSEPORT = 337,
+    VAR_VERSION = 338
   };
 #endif
 /* Tokens.  */
@@ -166,48 +167,49 @@ extern int yydebug;
 #define VAR_DO_IP6 293
 #define VAR_TCP_MSS 294
 #define VAR_OUTGOING_TCP_MSS 295
-#define VAR_ZONEFILE 296
-#define VAR_ZONE 297
-#define VAR_ALLOW_NOTIFY 298
-#define VAR_REQUEST_XFR 299
-#define VAR_NOTIFY 300
-#define VAR_PROVIDE_XFR 301
-#define VAR_NOTIFY_RETRY 302
-#define VAR_OUTGOING_INTERFACE 303
-#define VAR_ALLOW_AXFR_FALLBACK 304
-#define VAR_KEY 305
-#define VAR_ALGORITHM 306
-#define VAR_SECRET 307
-#define VAR_AXFR 308
-#define VAR_UDP 309
-#define VAR_VERBOSITY 310
-#define VAR_HIDE_VERSION 311
-#define VAR_PATTERN 312
-#define VAR_INCLUDEPATTERN 313
-#define VAR_ZONELISTFILE 314
-#define VAR_REMOTE_CONTROL 315
-#define VAR_CONTROL_ENABLE 316
-#define VAR_CONTROL_INTERFACE 317
-#define VAR_CONTROL_PORT 318
-#define VAR_SERVER_KEY_FILE 319
-#define VAR_SERVER_CERT_FILE 320
-#define VAR_CONTROL_KEY_FILE 321
-#define VAR_CONTROL_CERT_FILE 322
-#define VAR_XFRDIR 323
-#define VAR_RRL_SIZE 324
-#define VAR_RRL_RATELIMIT 325
-#define VAR_RRL_SLIP 326
-#define VAR_RRL_IPV4_PREFIX_LENGTH 327
-#define VAR_RRL_IPV6_PREFIX_LENGTH 328
-#define VAR_RRL_WHITELIST_RATELIMIT 329
-#define VAR_RRL_WHITELIST 330
-#define VAR_ZONEFILES_CHECK 331
-#define VAR_ZONEFILES_WRITE 332
-#define VAR_LOG_TIME_ASCII 333
-#define VAR_ROUND_ROBIN 334
-#define VAR_ZONESTATS 335
-#define VAR_REUSEPORT 336
-#define VAR_VERSION 337
+#define VAR_IP_FREEBIND 296
+#define VAR_ZONEFILE 297
+#define VAR_ZONE 298
+#define VAR_ALLOW_NOTIFY 299
+#define VAR_REQUEST_XFR 300
+#define VAR_NOTIFY 301
+#define VAR_PROVIDE_XFR 302
+#define VAR_NOTIFY_RETRY 303
+#define VAR_OUTGOING_INTERFACE 304
+#define VAR_ALLOW_AXFR_FALLBACK 305
+#define VAR_KEY 306
+#define VAR_ALGORITHM 307
+#define VAR_SECRET 308
+#define VAR_AXFR 309
+#define VAR_UDP 310
+#define VAR_VERBOSITY 311
+#define VAR_HIDE_VERSION 312
+#define VAR_PATTERN 313
+#define VAR_INCLUDEPATTERN 314
+#define VAR_ZONELISTFILE 315
+#define VAR_REMOTE_CONTROL 316
+#define VAR_CONTROL_ENABLE 317
+#define VAR_CONTROL_INTERFACE 318
+#define VAR_CONTROL_PORT 319
+#define VAR_SERVER_KEY_FILE 320
+#define VAR_SERVER_CERT_FILE 321
+#define VAR_CONTROL_KEY_FILE 322
+#define VAR_CONTROL_CERT_FILE 323
+#define VAR_XFRDIR 324
+#define VAR_RRL_SIZE 325
+#define VAR_RRL_RATELIMIT 326
+#define VAR_RRL_SLIP 327
+#define VAR_RRL_IPV4_PREFIX_LENGTH 328
+#define VAR_RRL_IPV6_PREFIX_LENGTH 329
+#define VAR_RRL_WHITELIST_RATELIMIT 330
+#define VAR_RRL_WHITELIST 331
+#define VAR_ZONEFILES_CHECK 332
+#define VAR_ZONEFILES_WRITE 333
+#define VAR_LOG_TIME_ASCII 334
+#define VAR_ROUND_ROBIN 335
+#define VAR_ZONESTATS 336
+#define VAR_REUSEPORT 337
+#define VAR_VERSION 338
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -218,7 +220,7 @@ union YYSTYPE
 
 	char*	str;
 
-#line 222 "configparser.h" /* yacc.c:1909  */
+#line 224 "configparser.h" /* yacc.c:1909  */
 };
 
 typedef union YYSTYPE YYSTYPE;
