@@ -609,6 +609,12 @@ struct additional_rr_types default_additional_rr_types[] = {
 	{ 0, (rr_section_type) 0 }
 };
 
+struct additional_rr_types swap_aaaa_additional_rr_types[] = {
+	{ TYPE_AAAA, ADDITIONAL_A_SECTION },
+	{ TYPE_A, ADDITIONAL_AAAA_SECTION },
+	{ 0, (rr_section_type) 0 }
+};
+
 struct additional_rr_types rt_additional_rr_types[] = {
 	{ TYPE_A, ADDITIONAL_A_SECTION },
 	{ TYPE_AAAA, ADDITIONAL_AAAA_SECTION },
@@ -698,8 +704,11 @@ add_rrset(struct query   *query,
 	result = answer_add_rrset(answer, section, owner, rrset);
 	switch (rrset_rrtype(rrset)) {
 	case TYPE_NS:
+		/* if query over IPv6, swap A and AAAA; put AAAA first */
 		add_additional_rrsets(query, answer, rrset, 0, 1,
-				      default_additional_rr_types);
+			(query->addr.ss_family == AF_INET6)?
+			swap_aaaa_additional_rr_types:
+			default_additional_rr_types);
 		break;
 	case TYPE_MB:
 		add_additional_rrsets(query, answer, rrset, 0, 0,
@@ -1000,6 +1009,7 @@ answer_authoritative(struct nsd   *nsd,
 {
 	domain_type *match;
 	domain_type *original = closest_match;
+	domain_type *dname_ce;
 	rrset_type *rrset;
 
 #ifdef NSEC3
@@ -1009,6 +1019,11 @@ answer_authoritative(struct nsd   *nsd,
 			closest_encloser = closest_encloser->parent;
 	}
 #endif /* NSEC3 */
+	if((dname_ce = find_dname_above(closest_encloser, q->zone)) != NULL) {
+		/* occlude the found data, the DNAME is closest_encloser */
+		closest_encloser = dname_ce;
+		exact = 0;
+	}
 
 	if (exact) {
 		match = closest_match;
@@ -1217,6 +1232,9 @@ answer_lookup_zone(struct nsd *nsd, struct query *q, answer_type *answer,
 	} else {
 		q->delegation_domain = domain_find_ns_rrsets(
 			closest_encloser, q->zone, &q->delegation_rrset);
+		if(q->delegation_domain && find_dname_above(q->delegation_domain, q->zone)) {
+			q->delegation_domain = NULL; /* use higher DNAME */
+		}
 
 		if (!q->delegation_domain
 		    || (exact && q->qtype == TYPE_DS && closest_encloser == q->delegation_domain))
