@@ -1,19 +1,19 @@
-/* A Bison parser, made by GNU Bison 2.7.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989-1990, 2000-2012 Free Software Foundation, Inc.
-   
+
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -26,13 +26,13 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
 #ifndef YY_YY_ZPARSER_H_INCLUDED
 # define YY_YY_ZPARSER_H_INCLUDED
-/* Enabling traces.  */
+/* Debug traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
 #endif
@@ -40,98 +40,98 @@
 extern int yydebug;
 #endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     T_A = 258,
-     T_NS = 259,
-     T_MX = 260,
-     T_TXT = 261,
-     T_CNAME = 262,
-     T_AAAA = 263,
-     T_PTR = 264,
-     T_NXT = 265,
-     T_KEY = 266,
-     T_SOA = 267,
-     T_SIG = 268,
-     T_SRV = 269,
-     T_CERT = 270,
-     T_LOC = 271,
-     T_MD = 272,
-     T_MF = 273,
-     T_MB = 274,
-     T_MG = 275,
-     T_MR = 276,
-     T_NULL = 277,
-     T_WKS = 278,
-     T_HINFO = 279,
-     T_MINFO = 280,
-     T_RP = 281,
-     T_AFSDB = 282,
-     T_X25 = 283,
-     T_ISDN = 284,
-     T_RT = 285,
-     T_NSAP = 286,
-     T_NSAP_PTR = 287,
-     T_PX = 288,
-     T_GPOS = 289,
-     T_EID = 290,
-     T_NIMLOC = 291,
-     T_ATMA = 292,
-     T_NAPTR = 293,
-     T_KX = 294,
-     T_A6 = 295,
-     T_DNAME = 296,
-     T_SINK = 297,
-     T_OPT = 298,
-     T_APL = 299,
-     T_UINFO = 300,
-     T_UID = 301,
-     T_GID = 302,
-     T_UNSPEC = 303,
-     T_TKEY = 304,
-     T_TSIG = 305,
-     T_IXFR = 306,
-     T_AXFR = 307,
-     T_MAILB = 308,
-     T_MAILA = 309,
-     T_DS = 310,
-     T_DLV = 311,
-     T_SSHFP = 312,
-     T_RRSIG = 313,
-     T_NSEC = 314,
-     T_DNSKEY = 315,
-     T_SPF = 316,
-     T_NSEC3 = 317,
-     T_IPSECKEY = 318,
-     T_DHCID = 319,
-     T_NSEC3PARAM = 320,
-     T_TLSA = 321,
-     T_URI = 322,
-     T_NID = 323,
-     T_L32 = 324,
-     T_L64 = 325,
-     T_LP = 326,
-     T_EUI48 = 327,
-     T_EUI64 = 328,
-     T_CAA = 329,
-     T_CDS = 330,
-     T_CDNSKEY = 331,
-     DOLLAR_TTL = 332,
-     DOLLAR_ORIGIN = 333,
-     NL = 334,
-     SP = 335,
-     STR = 336,
-     PREV = 337,
-     BITLAB = 338,
-     T_TTL = 339,
-     T_RRCLASS = 340,
-     URR = 341,
-     T_UTYPE = 342
-   };
+  enum yytokentype
+  {
+    T_A = 258,
+    T_NS = 259,
+    T_MX = 260,
+    T_TXT = 261,
+    T_CNAME = 262,
+    T_AAAA = 263,
+    T_PTR = 264,
+    T_NXT = 265,
+    T_KEY = 266,
+    T_SOA = 267,
+    T_SIG = 268,
+    T_SRV = 269,
+    T_CERT = 270,
+    T_LOC = 271,
+    T_MD = 272,
+    T_MF = 273,
+    T_MB = 274,
+    T_MG = 275,
+    T_MR = 276,
+    T_NULL = 277,
+    T_WKS = 278,
+    T_HINFO = 279,
+    T_MINFO = 280,
+    T_RP = 281,
+    T_AFSDB = 282,
+    T_X25 = 283,
+    T_ISDN = 284,
+    T_RT = 285,
+    T_NSAP = 286,
+    T_NSAP_PTR = 287,
+    T_PX = 288,
+    T_GPOS = 289,
+    T_EID = 290,
+    T_NIMLOC = 291,
+    T_ATMA = 292,
+    T_NAPTR = 293,
+    T_KX = 294,
+    T_A6 = 295,
+    T_DNAME = 296,
+    T_SINK = 297,
+    T_OPT = 298,
+    T_APL = 299,
+    T_UINFO = 300,
+    T_UID = 301,
+    T_GID = 302,
+    T_UNSPEC = 303,
+    T_TKEY = 304,
+    T_TSIG = 305,
+    T_IXFR = 306,
+    T_AXFR = 307,
+    T_MAILB = 308,
+    T_MAILA = 309,
+    T_DS = 310,
+    T_DLV = 311,
+    T_SSHFP = 312,
+    T_RRSIG = 313,
+    T_NSEC = 314,
+    T_DNSKEY = 315,
+    T_SPF = 316,
+    T_NSEC3 = 317,
+    T_IPSECKEY = 318,
+    T_DHCID = 319,
+    T_NSEC3PARAM = 320,
+    T_TLSA = 321,
+    T_URI = 322,
+    T_NID = 323,
+    T_L32 = 324,
+    T_L64 = 325,
+    T_LP = 326,
+    T_EUI48 = 327,
+    T_EUI64 = 328,
+    T_CAA = 329,
+    T_CDS = 330,
+    T_CDNSKEY = 331,
+    T_CSYNC = 332,
+    DOLLAR_TTL = 333,
+    DOLLAR_ORIGIN = 334,
+    NL = 335,
+    SP = 336,
+    STR = 337,
+    PREV = 338,
+    BITLAB = 339,
+    T_TTL = 340,
+    T_RRCLASS = 341,
+    URR = 342,
+    T_UTYPE = 343
+  };
 #endif
 /* Tokens.  */
 #define T_A 258
@@ -208,25 +208,25 @@ extern int yydebug;
 #define T_CAA 329
 #define T_CDS 330
 #define T_CDNSKEY 331
-#define DOLLAR_TTL 332
-#define DOLLAR_ORIGIN 333
-#define NL 334
-#define SP 335
-#define STR 336
-#define PREV 337
-#define BITLAB 338
-#define T_TTL 339
-#define T_RRCLASS 340
-#define URR 341
-#define T_UTYPE 342
-
-
+#define T_CSYNC 332
+#define DOLLAR_TTL 333
+#define DOLLAR_ORIGIN 334
+#define NL 335
+#define SP 336
+#define STR 337
+#define PREV 338
+#define BITLAB 339
+#define T_TTL 340
+#define T_RRCLASS 341
+#define URR 342
+#define T_UTYPE 343
 
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+
+union YYSTYPE
 {
-/* Line 2058 of yacc.c  */
-#line 50 "zparser.y"
+#line 50 "zparser.y" /* yacc.c:1909  */
 
 	domain_type	 *domain;
 	const dname_type *dname;
@@ -236,29 +236,17 @@ typedef union YYSTYPE
 	uint16_t	  type;
 	uint16_t	 *unknown;
 
+#line 240 "zparser.h" /* yacc.c:1909  */
+};
 
-/* Line 2058 of yacc.c  */
-#line 242 "zparser.h"
-} YYSTYPE;
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
-#ifdef YYPARSE_PARAM
-#if defined __STDC__ || defined __cplusplus
-int yyparse (void *YYPARSE_PARAM);
-#else
-int yyparse ();
-#endif
-#else /* ! YYPARSE_PARAM */
-#if defined __STDC__ || defined __cplusplus
 int yyparse (void);
-#else
-int yyparse ();
-#endif
-#endif /* ! YYPARSE_PARAM */
 
 #endif /* !YY_YY_ZPARSER_H_INCLUDED  */
